@@ -1,14 +1,18 @@
 from abc import (ABC,
                  abstractmethod)
-from typing import (Type,
+from typing import (Optional,
+                    Type,
                     TypeVar)
 
-from .hints import Domain
+from .hints import (Coordinate,
+                    Domain)
 
-RawGeometry = TypeVar('RawGeometry', tuple, list)
+RawGeometry = TypeVar('RawGeometry', None, tuple, list)
 
 
 class Geometry(ABC):
+    __slots__ = ()
+
     @abstractmethod
     def __eq__(self, other: 'Geometry') -> bool:
         """
@@ -40,6 +44,20 @@ class Geometry(ABC):
         Returns geometric object as combination of Python built-ins.
         """
 
+    @abstractmethod
+    def scale(self,
+              factor_x: Coordinate,
+              factor_y: Optional[Coordinate] = None) -> 'Geometry':
+        """
+        Scales geometric object by given factor.
+        """
+
+    @abstractmethod
+    def translate(self, step_x: Coordinate, step_y: Coordinate) -> 'Geometry':
+        """
+        Translates geometric object by given step.
+        """
+
     @abstractmethod
     def validate(self) -> None:
         """
